# Py-blueprints 

Flask blueprints ready to go

### Installing the package locally
```python
python setup.py install
```

### Installing the package with Pypi
```python
pip install py-blueprints
```

